require 'logger'

module SwaggerClient
  module Swagger
    class Configuration
      attr_accessor :format, :api_key, :api_key_prefix, :username, :password, :auth_token,
                    :scheme, :host, :base_path, :user_agent, :debug, :logger, :inject_format,
                    :force_ending_format, :camelize_params, :user_agent, :verify_ssl

      # Set this to customize the certificate file to verify the peer.
      #
      # @return [String] the path to the certificate file
      #
      # @see The `cainfo` option of Typhoeus, `--cert` option of libcurl. Related source code:
      #   https://github.com/typhoeus/typhoeus/blob/master/lib/typhoeus/easy_factory.rb#L145
      attr_accessor :ssl_ca_cert

      # Defaults go in here..
      def initialize
        @format = 'json'
        @scheme = 'http'
        @host = 'petstore.swagger.io'
        @base_path = '/v2'
        @user_agent = "ruby-swagger-#{Swagger::VERSION}"
        @inject_format = false
        @force_ending_format = false
        @camelize_params = true

        # keys for API key authentication (param-name => api-key)
        @api_key = {}
        # api-key prefix for API key authentication, e.g. "Bearer" (param-name => api-key-prefix)
        @api_key_prefix = {}

        # whether to verify SSL certificate, default to true
        # Note: do NOT set it to false in production code, otherwise you would
        #   face multiple types of cryptographic attacks
        @verify_ssl = true

        # whether to enable debugging
        @debug = false

        # configure logger, default to logger of Rails (if in Rails) or STDOUT
        @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT)
      end
    end
  end
end
